@@ -80,16 +80,16 @@ sub sim    # This function launch the simulations in ESP-r
 	$preventsim = $main::preventsim;
 	$fileconfig = $main::fileconfig; #say $tee "dumpINSIM(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
 	$outfile = $main::outfile;
-	$toshell = $main::toshell;
+	$tofile = $main::tofile;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
 	
-	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
+	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
 	say  "\nNow in Sim::OPT::Sim.\n";
-	say TOSHELL "\n#Now in Sim::OPT::Sim.\n";
+	say TOFILE "\n#Now in Sim::OPT::Sim.\n";
 	
 	%dowhat = %main::dowhat;
 
@@ -135,9 +135,9 @@ sub sim    # This function launch the simulations in ESP-r
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
 	
-	my $skipfile = $vals{skipfile}; say TOSHELL "dump(\$skipfile): " . dump($skipfile);
-	my $skipsim = $vals{skipsim}; say TOSHELL "dump(\$skipsim): " . dump($skipsim);
-	my $skipreport = $vals{skipreport}; say TOSHELL "dump(\$skipreport): " . dump($skipreport);
+	my $skipfile = $vals{skipfile}; say TOFILE "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; say TOFILE "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; say TOFILE "dump(\$skipreport): " . dump($skipreport);
 	
 	#my $getpars = shift;
 	#eval( $getpars );
@@ -145,33 +145,33 @@ sub sim    # This function launch the simulations in ESP-r
 	#if ( fileno (MORPHLIST) 
 
 	my @container;
-	say TOSHELL "dump(\@instances): " . dump(@instances);
+	say TOFILE "dump(\@instances): " . dump(@instances);
 	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
 		my %d = %{$instance};
-		my $countcase = $d{countcase}; #say TOSHELL "dump(\$countcase): " . dump($countcase);
-		my $countblock = $d{countblock}; #say TOSHELL "dump(\$countblock): " . dump($countblock);
-		my @miditers = @{ $d{miditers} }; #say TOSHELL "dump(\@miditers): " . dump(@miditers);
-		my @winneritems = @{ $d{winneritems} }; #say TOSHELL "dumpIN( \@winneritems) " . dump(@winneritems);
-		my $countvar = $d{countvar}; #say TOSHELL "dump(\$countvar): " . dump($countvar);
-		my $countstep = $d{countstep}; #say TOSHELL "dump(\$countstep): " . dump($countstep);						
-		my $to = $d{to}; say TOSHELL "dump(\$to): " . dump($to);
-		my $origin = $d{origin}; #say TOSHELL "dump(\$origin): " . dump($origin);
-		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
+		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
+		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
+		my @miditers = @{ $d{miditers} }; #say TOFILE "dump(\@miditers): " . dump(@miditers);
+		my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
+		my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
+		my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
+		my $to = $d{to}; say TOFILE "dump(\$to): " . dump($to);
+		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
+		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
 		
-		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
-		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
-		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
-		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOSHELL "dump(\$toitem): " . dump($toitem);
-		my $from = Sim::OPT::getline($toitem); #say TOSHELL "dumpIN(\$from): " . dump($from);
-		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOSHELL "dumpIN---(\%varnums): " . dump(%varnums); 
-		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOSHELL "dumpIN---(\%mids): " . dump(%mids); 
+		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
+		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
+		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
+		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOFILE "dump(\$toitem): " . dump($toitem);
+		my $from = Sim::OPT::getline($toitem); #say TOFILE "dumpIN(\$from): " . dump($from);
+		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
+		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
 		#eval($getfly);
 		
-		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOSHELL "dump(\$stepsvar): " . dump($stepsvar); 
-		my $varnumber = $countvar; #say TOSHELL "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
+		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
+		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 		
 		my @ress;
 		my @flfs;
@@ -183,37 +183,37 @@ sub sim    # This function launch the simulations in ESP-r
 		#my $prov =~ s/_-*$//;
 		#if ( not ( $to ~~ @{ $simcases[$countcase] } ) )
 		#{
-		#	push ( @simcases, $to ); say TOSHELL "simcases: " . dump(@simcases);
+		#	push ( @simcases, $to ); say TOFILE "simcases: " . dump(@simcases);
 		#	print SIMLIST "$to\n";
 		#}
 		
-		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say TOSHELL "\$numberof_simtools " . dump( $numberof_simtools );
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say TOFILE "\$numberof_simtools " . dump( $numberof_simtools );
 		my $simelt = $to;
 		
 		my $counttool = 1;
 		while ( $counttool <= $numberof_simtools )
 		{	
-			my $skip = $vals{$countvar}{$counttool}{skip}; say TOSHELL "dumpinsim(\$skip): " . dump($skip);
+			my $skip = $vals{$countvar}{$counttool}{skip}; say TOFILE "dumpinsim(\$skip): " . dump($skip);
 			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-				my $tooltype = $dowhat{simtools}{$counttool}; say TOSHELL "\$tooltype " . dump( $tooltype );
+				my $tooltype = $dowhat{simtools}{$counttool}; say TOFILE "\$tooltype " . dump( $tooltype );
 				
 				if ( $tooltype eq "esp-r" )
 				{	
-					say TOSHELL "dump(\%simtitles): " . dump( %simtitles ); 
-					say TOSHELL "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
-					say TOSHELL "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
+					say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
+					say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
+					say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
 					my $countsim = 0;		
 					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						my $date_to_sim = $simtitle_ref->[0]; say TOSHELL "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
-						my $begin = $simtitle_ref->[1]; say TOSHELL "dump(\$begin): " . dump($begin); 
-						my $end = $simtitle_ref->[2]; say TOSHELL "dump(\$end): " . dump($end); 
-						my $before = $simtitle_ref->[3]; say TOSHELL "dump(\$before): " . dump($before); 
-						my $step = $simtitle_ref->[4]; say TOSHELL "dump(\$step): " . dump($step); 
+						my $date_to_sim = $simtitle_ref->[0]; say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
+						my $begin = $simtitle_ref->[1]; say TOFILE "dump(\$begin): " . dump($begin); 
+						my $end = $simtitle_ref->[2]; say TOFILE "dump(\$end): " . dump($end); 
+						my $before = $simtitle_ref->[3]; say TOFILE "dump(\$before): " . dump($before); 
+						my $step = $simtitle_ref->[4]; say TOFILE "dump(\$step): " . dump($step); 
 						
-						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; say TOSHELL "dump(\$resfile): " . dump($resfile); 
-						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; say TOSHELL "dump(\$flfile): " . dump($flfile); 
+						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; say TOFILE "dump(\$resfile): " . dump($resfile); 
+						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; say TOFILE "dump(\$flfile): " . dump($flfile); 
 
 						#if ( fileno (SIMLIST) )
 						#if (not (-e $simlist ) )
@@ -292,7 +292,7 @@ XXX
 									{
 										print `$printthis`;
 									}
-									print TOSHELL " 	
+									print TOFILE " 	
 			#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
 			$printthis
 			\n";
@@ -328,7 +328,7 @@ XXX
 									{
 										print `$printthis`;
 									}
-									print TOSHELL "  
+									print TOFILE "  
 $printthis
 ";
 								}					
@@ -343,28 +343,28 @@ $printthis
 					my $countsim = 0;			
 					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						my $date_to_sim = $simtitle_ref->[0]; say TOSHELL "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
-						my $begin = $simtitle_ref->[1]; say TOSHELL "dump(\$begin): " . dump($begin); 
-						my $end = $simtitle_ref->[2]; say TOSHELL "dump(\$end): " . dump($end); 
-						my $before = $simtitle_ref->[3]; say TOSHELL "dump(\$before): " . dump($before); 
-						my $step = $simtitle_ref->[4]; say TOSHELL "dump(\$step): " . dump($step); 
+						my $date_to_sim = $simtitle_ref->[0]; say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
+						my $begin = $simtitle_ref->[1]; say TOFILE "dump(\$begin): " . dump($begin); 
+						my $end = $simtitle_ref->[2]; say TOFILE "dump(\$end): " . dump($end); 
+						my $before = $simtitle_ref->[3]; say TOFILE "dump(\$before): " . dump($before); 
+						my $step = $simtitle_ref->[4]; say TOFILE "dump(\$step): " . dump($step); 
 						 
-						my $epw = $simtitle_ref->[5]; say TOSHELL "dump(\$epw ): " . dump( $epw ); 
-						my $epwfile = $mypath . "/" . $epw; say TOSHELL"\$epwfile " . dump( $epwfile );
-						my $epdir = $simtitle_ref->[6]; say TOSHELL "dump(\$epdir ): " . dump( $epdir ); 
-						my $epoldfile = $simtitle_ref->[7]; say TOSHELL "dump(\$epoldfile ): " . dump( $epoldfile ); 
-						my $epnewfragment = $simtitle_ref->[8]; say TOSHELL "dump(\$epnewfragment ): " . dump( $epnewfragment );  
-						my $outputdir = $simtitle_ref->[9]; say TOSHELL "dump(\$outputdir ): " . dump( $outputdir ); 
-						my $modfiletype = $simtitle_ref->[10]; say TOSHELL "dump(\$modfiletype ): " . dump( $modfiletype ); 
-						my $resfiletype = $simtitle_ref->[11]; say TOSHELL "dump(\$resfiletype ): " . dump( $resfiletype ); 
-						my $epoldpath = $to . $epdir . "/" . $epoldfile; say TOSHELL "dump(\$epoldpath ): " . dump( $epoldpath ); 
+						my $epw = $simtitle_ref->[5]; say TOFILE "dump(\$epw ): " . dump( $epw ); 
+						my $epwfile = $mypath . "/" . $epw; say TOFILE"\$epwfile " . dump( $epwfile );
+						my $epdir = $simtitle_ref->[6]; say TOFILE "dump(\$epdir ): " . dump( $epdir ); 
+						my $epoldfile = $simtitle_ref->[7]; say TOFILE "dump(\$epoldfile ): " . dump( $epoldfile ); 
+						my $epnewfragment = $simtitle_ref->[8]; say TOFILE "dump(\$epnewfragment ): " . dump( $epnewfragment );  
+						my $outputdir = $simtitle_ref->[9]; say TOFILE "dump(\$outputdir ): " . dump( $outputdir ); 
+						my $modfiletype = $simtitle_ref->[10]; say TOFILE "dump(\$modfiletype ): " . dump( $modfiletype ); 
+						my $resfiletype = $simtitle_ref->[11]; say TOFILE "dump(\$resfiletype ): " . dump( $resfiletype ); 
+						my $epoldpath = $to . $epdir . "/" . $epoldfile; say TOFILE "dump(\$epoldpath ): " . dump( $epoldpath ); 
 						my $tempname = $to;
-						$tempname =~ s/$mypath\/// ; say TOSHELL "dump(\$tempname ): " . dump( $tempname ); 
-						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; say TOSHELL "dump(\$epnewfile ): " . dump( $epnewfile ); 
-						my $epresroot = $tempname . $epnewfragment ; say TOSHELL "dump(\$epnewfile ): " . dump( $epnewfile ); 
-						my $epnewpath = $to . $epdir . "/" . $epnewfile; say TOSHELL "dump(\$epnewpath ): " . dump( $epnewpath ); 
+						$tempname =~ s/$mypath\/// ; say TOFILE "dump(\$tempname ): " . dump( $tempname ); 
+						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						my $epresroot = $tempname . $epnewfragment ; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						my $epnewpath = $to . $epdir . "/" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
 						my @simdos = @{ $simtitle_ref };
-						my @changes = @simdos[ 12..$#simdos ]; say TOSHELL "dump(\@changes ): " . dump( @changes ); 
+						my @changes = @simdos[ 12..$#simdos ]; say TOFILE "dump(\@changes ): " . dump( @changes ); 
 						if ( $tooltype eq "energyplus" ) # RESTORES DEFAULTS FOR ENERGYPLUS
 						{
 							$outputdir = "/Output";
@@ -377,7 +377,7 @@ $printthis
 						
 						open ( EPOLDPATH, "$epoldpath" ) or die( "$!" );
 						my @sourcecontents = <EPOLDPATH>;
-						close EPOLDPATH; #say TOSHELL "dump(\@sourcecontents ): " . dump( @sourcecontents ); 
+						close EPOLDPATH; #say TOFILE "dump(\@sourcecontents ): " . dump( @sourcecontents ); 
 						
 						unless ( -e $epnewpath )
 						{
@@ -386,9 +386,9 @@ $printthis
 							{
 								foreach my $change ( @changes )
 								{
-									my $source = $change->[0]; #say T say TOSHELL "dump(\$source ): " . dump( $source ); 
-									my $target = $change->[1]; #say TOSHELL "dump(\$target ): " . dump( $target ); say TOSHELL "dump(\$rowBEFORE ): " . dump( $row ); 
-									$row =~ s/$source/$target/ ; #say TOSHELL "dump(\$rowAFTER ): " . dump( $row ); 
+									my $source = $change->[0]; #say T say TOFILE "dump(\$source ): " . dump( $source ); 
+									my $target = $change->[1]; #say TOFILE "dump(\$target ): " . dump( $target ); say TOFILE "dump(\$rowBEFORE ): " . dump( $row ); 
+									$row =~ s/$source/$target/ ; #say TOFILE "dump(\$rowAFTER ): " . dump( $row ); 
 								}
 								print EPNEWPATH $row;
 
@@ -396,10 +396,10 @@ $printthis
 							close EPNEWPATH;
 						}
 						
-						my $file_eplus = "$to/$file_eplus";  #say TOSHELL "dump(\$file_eplus ): " . dump( $file_eplus ); 
+						my $file_eplus = "$to/$file_eplus";  #say TOFILE "dump(\$file_eplus ): " . dump( $file_eplus ); 
 						
-						my $simelt = $mypath . "$outputdir"; #say TOSHELL "dump(\$simelt ): " . dump( $simelt ); 
-						my $resfile = "$simelt/$epresroot$resfiletype"; #say TOSHELL "dump(\$resfile ): " . dump( $resfile ); 
+						my $simelt = $mypath . "$outputdir"; #say TOFILE "dump(\$simelt ): " . dump( $simelt ); 
+						my $resfile = "$simelt/$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
 						
 						if (not (-e $simblock ) )
 						{
@@ -462,16 +462,16 @@ $printthis
 								{
 									unless ( $exeonfiles eq "n" )
 										{
-										my $tempf = $epnewpath; #say TOSHELL "dump(\$tempf1 ): " . dump( $tempf ); 
-										$tempf =~ s/$to$epdir\///;  #say TOSHELL "dump(\$tempf2 ): " . dump( $tempf ); 
-										$templaunch = $mypath . "/" . $tempf; #say TOSHELL "dump(\$templaunch ): " . dump( $templaunch ); 
+										my $tempf = $epnewpath; #say TOFILE "dump(\$tempf1 ): " . dump( $tempf ); 
+										$tempf =~ s/$to$epdir\///;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
+										$templaunch = $mypath . "/" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
 										`cp -f $epnewpath $templaunch`;
 										`runenergyplus $templaunch $epwfile`;
 										#`rm -f $templaunch`;
 									}
-									print TOSHELL "cp -f $epnewpath $templaunch\n";
-									print TOSHELL "runenergyplus $templaunch $epwfile\n";
-									#print TOSHELL "rm -f $templaunch\n";
+									print TOFILE "cp -f $epnewpath $templaunch\n";
+									print TOFILE "runenergyplus $templaunch $epwfile\n";
+									#print TOFILE "rm -f $templaunch\n";
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: using $epnewpath (actually $templaunch) to obtain $resfile. " ;										
 								}
 							}	
@@ -486,10 +486,10 @@ $printthis
 	}
 	close SIMLIST;
 	close SIMBLOCK;
-	say TOSHELL "dump(\@simcases ): " . dump( @simcases ); 
-	say TOSHELL "dump(\@simstruct ): " . dump( @simstruct ); 
+	say TOFILE "dump(\@simcases ): " . dump( @simcases ); 
+	say TOFILE "dump(\@simstruct ): " . dump( @simstruct ); 
 	return ( \@simcases, \@simstruct );
-	close TOSHELL;
+	close TOFILE;
 	close OUTFILE;
 }    # END SUB sim;			
 
